ig.module(
    'game.entities.cannon'
)
.requires(
    'impact.entity'
)
.defines(function(){
    
EntityCannon = ig.Entity.extend({
    size: {x:30, y:18},
    maxVel: {x:0, y:0},
    collides: ig.Entity.COLLIDES.PASSIVE,
    checkAgainst: ig.Entity.TYPE.A,
    type: ig.Entity.TYPE.B,  //Enemy
    image: new ig.Image('media/cannonW.png'),
    imageE: new ig.Image('media/cannonE.png'),
    image_inv: new ig.Image('media/cannonT.png'),
    image_invE: new ig.Image('media/cannonTE.png'),
    sfxExplosion: new ig.Sound( 'media/boom.ogg' ),
    sfxHit: new ig.Sound( 'media/ping.ogg' ),
    sfxFire: new ig.Sound( 'media/shoot_enemy.ogg' ),
    fireTimer: undefined,
    inverted: false,
    canShoot: true,
    health: 2,
    value: 75,
    
    init: function( x, y, settings ) {
        this.parent( x, y, settings );
        this.vel.x = 0;
        this.vel.y = 0;
        this.fireTimer = new ig.Timer();
        this.fireTimer.set(2); //s
    },
    
    update: function() {
        if(this.fireTimer.delta()>0){
            this.canShoot = true;
        }
        
        this.parent();
        if (this.pos.x < 0) {
            this.pos.x = 0;
            this.vel.x = -this.vel.x;
        } else if (this.pos.x > (ig.system.width-this.size.x)) {
            this.pos.x = (ig.system.width-this.size.x);
            this.vel.x = -this.vel.x;
        }
        
        if(this.canShoot) {
            var player = ig.game.getEntityByName('player');
            if (player === undefined) return;
            if (this.orientation == 'E') {
                if ((player.pos.x > this.pos.x) && (player.pos.x < this.pos.x + 500)) {
                    this.fire();
                }
            } else {
                if ((player.pos.x < this.pos.x) && (player.pos.x > this.pos.x - 500)) {
                    this.fire();
                }
            }
        }
    },
    
    fire: function() {
        var x=this.pos.x-6,y,vx=-200;
        if (this.inverted) {
            y = this.pos.y + this.size.y - 3;
        } else {
            y = this.pos.y + 3;
        }
        if (this.orientation == 'E') {
                x = this.pos.x + this.size.x;
                vx = -vx;
            }
        ig.game.spawnEntity(EntityEnemyBullet, x, y, {vx: vx});
        this.sfxFire.play();
        this.canShoot = false;
        this.fireTimer.reset();
    },
    draw: function() {
        var img;
        if (this.inverted) {
            if (this.orientation == 'E') {
                img = this.image_invE;
            } else {
                img = this.image_inv;
            }
        } else if (this.orientation == 'E') {
            img = this.imageE;
        } else {
            img = this.image;
        }
        img.draw(this.pos.x, this.pos.y);
        this.parent();
    },
    check: function(other) {
        other.kill();
    },
    kill: function() {
        this.parent();
        this.sfxExplosion.play();
        ig.game.score += this.value;
    },
    receiveDamage: function(amount, other) {
        this.parent(amount, other);
        this.sfxHit.play();
    }
});


});
