ig.module(
    'game.entities.rotatingcannon'
)
.requires(
    'impact.entity'
)
.defines(function(){
    
EntityRotatingcannon = ig.Entity.extend({
    size: {x:30, y:22},
    maxVel: {x:0, y:0},
    image: new ig.Image('media/rotating.png'),
    collides: ig.Entity.COLLIDES.PASSIVE,
    checkAgainst: ig.Entity.TYPE.A,
    type: ig.Entity.TYPE.B,  //Enemy
    sfxExplosion: new ig.Sound( 'media/boom.ogg' ),
    sfxHit: new ig.Sound( 'media/ping.ogg' ),
    sfxFire: new ig.Sound( 'media/shoot_enemy.ogg' ),
    fireTimer: undefined,
    canShoot: true,
    health: 3,
    tile: 0,
    value: 95,
    
    init: function( x, y, settings ) {
        this.parent( x, y, settings );
        this.vel.x = 0;
        this.vel.y = 0;
        this.fireTimer = new ig.Timer();
        this.fireTimer.set(2); //s
        this.orientation = settings.orientation || 'N';
    },
    
    update: function() {
        if(this.fireTimer.delta()>0){
            this.canShoot = true;
        }
        
        this.parent();
        var player = ig.game.getEntityByName('player');
        if (player) {
            var alpha = this.angleTo(player);
            if (alpha < -7*Math.PI / 8) {
                this.tile = 0;
            } else if (alpha < -5*Math.PI / 8) {
                this.tile = 1;
            } else if (alpha < -3*Math.PI / 8) {
                this.tile = 2;
            } else if (alpha < -Math.PI / 8) {
                this.tile = 3;
            } else if (alpha < 0) {
                this.tile = 4;
            }
            else if (alpha < Math.PI / 8) {
                this.tile = 4;
            } else if (alpha < 3*Math.PI / 8) {
                this.tile = 3;
            } else if (alpha < 5*Math.PI / 8) {
                this.tile = 2;
            } else if (alpha < 7*Math.PI / 8) {
                this.tile = 1;
            } else {
                this.tile = 0;
            }
            if(this.canShoot) {
            
            
//             if ((player.pos.x < this.pos.x) && (player.pos.x > this.pos.x - 500)) {
                this.fire(player.pos.x - this.pos.x, player.pos.y - this.pos.y);
//             }
            }
        }
    },
    
    fire: function(vx, vy) {
        if (this.canShoot) {
            var bulletX=0, bulletY=0;
            switch (this.orientation) {
                case 'N':
                    if (vy >= 0) return;
                    bulletX = this.pos.x+(this.size.x/2)-1;
                    bulletY = this.pos.y-6;
                    break;
                case 'S':
                    if (vy <= 0) return;
                    bulletX = this.pos.x+(this.size.x/2)-1;
                    bulletY = this.pos.y+this.size.y;
                    break;
                case 'E':
                    if (vx >= 0) return;
                    bulletX = this.pos.x-6;
                    bulletY = this.pos.y+(this.size.y/2)-1;
                    break;
                case 'W':
                    if (vx <= 0) return;
                    bulletX = this.pos.x+this.size.x + 1;
                    bulletY = this.pos.y+(this.size.y/2)-1;
                    break;
            }
            ig.game.spawnEntity(EntityEnemyBullet, bulletX, bulletY, {vx: vx, vy: vy});
            this.sfxFire.play();
            this.canShoot = false;
            this.fireTimer.reset();
        }
    },
    draw: function() {
       this.image.drawTile(this.pos.x, this.pos.y, this.tile, this.size.x, this.size.y, 
                           false, this.orientation == 'N' ? true: false); 
       this.parent();
//       .drawTile( targetX, targetY, tile, tileWidth, [tileHeight], [flipX], [flipY] )

    },
    check: function(other) {
        other.kill();
    },
    kill: function() {
        this.parent();
        this.sfxExplosion.play();
        ig.game.score += this.value;
    },
    receiveDamage: function(amount, other) {
        this.parent(amount, other);
        this.sfxHit.play();
    }
});


});
