ARENA_WIDTH=630;
ARENA_HEIGHT=450;
BULLET_SPEED=400;
END=12;

ig.module( 
	'game.main' 
)
.requires(
	'impact.game',
	'impact.font',
    
    'game.entities.cannon',
    'game.entities.rotatingcannon',
    'game.entities.missil',
    'game.entities.laser',
    'game.entities.barrier',
    'game.entities.player',
    
    'game.levels.L0',
    'game.levels.L1',
    'game.levels.L2',
    'game.levels.L3',
    'game.levels.L4',
    'game.levels.L5',
    'game.levels.L6',
    'game.levels.L7',
    'game.levels.L8',
    'game.levels.L9',
    'game.levels.L10',
    'game.levels.L11',
    'game.levels.L12',
    'game.levels.L13',
    'game.levels.L14',
    'game.levels.L15',
    'game.levels.L16'
)
.defines(function(){


EntityBullet = ig.Entity.extend({
    size: {x: 6, y: 2},
    vel: {x: 400, y: 0},
    maxVel: {x:600, y:0},
    collides: ig.Entity.COLLIDES.PASSIVE,
    type: ig.Entity.TYPE.NONE,
    checkAgainst: ig.Entity.TYPE.B,
    init: function( x, y, settings ) {
        this.parent( x, y, settings );
        if (settings.vx !== undefined) {
            this.vel.x = settings.vx;
        }
        if (settings.vy !== undefined) {
            this.vel.y = settings.vy;
        }
    },
    draw: function() {
        var ctx = ig.system.context;
        var s = ig.system.scale;
        var x = this.pos.x * s; // - ig.game.screen.x * s;
        var y = this.pos.y * s; // - ig.game.screen.y * s;
        var sizeX = this.size.x * s;
        var sizeY = this.size.y * s;
        ctx.fillStyle = "rgb(0,200,0)";
        ctx.fillRect (x, y, sizeX, sizeY);
    },
    update: function() {
        if (this.pos.x > ig.system.width ) {
            this.kill();
        }
        this.parent();
    },
    check: function(other) {
        other.receiveDamage(1, this);
        this.kill();
    },
    handleMovementTrace: function( res ) {
        this.parent(res);
        if (res.collision.x || res.collision.y) {
            this.kill();
        }
    }
})

EntityEnemyBullet = ig.Entity.extend({
    size: {x: 6, y: 2},
    vel: {x: -150, y: 0},
    maxVel: {x:600, y:600},
    collides: ig.Entity.COLLIDES.PASSIVE,
    type: ig.Entity.TYPE.NONE,
    checkAgainst: ig.Entity.TYPE.A,
    init: function( x, y, settings ) {
        this.parent( x, y, settings );
        if (settings.vx !== undefined) {
            this.vel.x = settings.vx;
        }
        if (settings.vy !== undefined) {
            this.vel.y = settings.vy;
        }
    },
    draw: function() {
        var ctx = ig.system.context;
        var s = ig.system.scale;
        var x = this.pos.x * s; // - ig.game.screen.x * s;
        var y = this.pos.y * s; // - ig.game.screen.y * s;
        var sizeX = this.size.x * s;
        var sizeY = this.size.y * s;
        ctx.fillStyle = "rgb(0,200,0)";
        ctx.fillRect (x, y, sizeX, sizeY);
    },
    update: function() {
        if ((this.pos.x < 0) || (this.pos.x > ig.system.width) ||
            (this.pos.y < 0) || (this.pos.y > ig.system.height))
        {
            this.kill();
        }
        this.parent();
    },
    check: function(other) {
        other.kill();
        this.kill();
    },
    handleMovementTrace: function( res ) {
        this.parent(res);
        if (res.collision.x || res.collision.y) {
            this.kill();
        }
    }
})

MyGame = ig.Game.extend({
    level: -1, //-1,
    prevX: 0,
    prevY: 200,
    endMusic: new ig.Sound( 'media/3.ogg' ),
	
	init: function() {
		// Initialize your game here; bind keys etc.
        ig.input.bind(ig.KEY.LEFT_ARROW, 'left');
        ig.input.bind(ig.KEY.RIGHT_ARROW, 'right');
        ig.input.bind(ig.KEY.UP_ARROW, 'up');
        ig.input.bind(ig.KEY.DOWN_ARROW, 'down');
        ig.input.bind(ig.KEY.SPACE, 'fire');
        this.lives = 3;
        this.score = 0;
        this.changeLevel();
	},
    death: function() {
        this.lives--;
        if (this.lives == -1) {
            document.getElementById('game-over').style.display = 'block';
        } else {
            var w = this.lives * 15 - 1;
            if (w < 0) w = 0;
            document.getElementById('lives').style.width = w.toString() + 'px';
            this.deathTimer = new ig.Timer(1);
        }
    },
	update: function() {

        this.parent();
        // Update all entities and backgroundMaps
		// Add your own, additional update code here
        if (this.deathTimer && (this.deathTimer.delta()>0)) {
            ig.game.changeLevel(true);
            this.deathTimer = null;
        }
        document.getElementById('score').innerHTML = this.score.toString();
        if (this.lives == -1) {
            if( ig.input.pressed('fire')) {
                document.getElementById('game-over').style.display = 'none';
                ig.system.setGame( MyTitle );
                return;
            }
        }
	},
	
	draw: function() {
		// Draw all entities and backgroundMaps
		this.parent();
	},
    
    changeLevel: function(restart) {
        if (!restart) {
            this.level++;
            if (this.level == END) {
                ig.system.setGame( MyEnd );
                return;
            }
        }
        this.loadLevelDeferred( ig.global['LevelL' + this.level.toString()] );
    },
    
    loadLevel: function(data) {
        var x=undefined,y=undefined,facing;
        var player = ig.game.getEntityByName('player');
        if (player && !player.dead) {
            x = player.pos.x;
            y = player.pos.y;
            if (x < 60) x = ig.system.width - 30;
            else if (x > ig.system.width-70) x = 0;
            if (y < 60) y = ig.system.height - 30;
            else if (y > ig.system.height-70) y = 0;
            facing = player.facing;
        }
        this.parent(data);
        player = ig.game.getEntityByName('player');
        if (x) {
            player.pos.x = x;
        }
        if (y) {
            player.pos.y = y;
        }
        if (facing) {
            player.facing = facing;
        }
    }
});

MyTitle = ig.Game.extend({
    startMusic: new ig.Sound( 'media/4.ogg' ),
    init: function() {
        ig.input.bind(ig.KEY.SPACE, 'fire');
        this.startMusic.volume = 0.5;
        this.startMusic.play();
        
    },
    update: function() {
        // Check for buttons; start the game if pressed
        if( ig.input.pressed('fire')) {
            this.startMusic.stop();
            ig.system.setGame( MyGame );
            return;
        }
    }
});

MyEnd = ig.Game.extend({
    endMusic: new ig.Sound( 'media/3.ogg' ),
    init: function() {
        ig.input.bind(ig.KEY.SPACE, 'fire');
        this.endMusic.volume = 0.5;
        this.endMusic.play();
        document.getElementById('thx').style.display = 'block';
    },
    update: function() {
        // Check for buttons; start the game if pressed
        if( ig.input.pressed('fire')) {
            this.endMusic.stop();
            document.getElementById('thx').style.display = 'none';
            ig.system.setGame( MyTitle );
            return;
        }
    }
});
// Start the Game with 60fps, a resolution of ARENA_WIDTH x ARENA_HEIGHT, scaled
// up by a factor of 1
ig.main( '#canvas', MyTitle, 60, ARENA_WIDTH, ARENA_HEIGHT, 1 );

});
